@@ -40,6 +40,8 @@ import xdg.Mime
 # Local modules
 from .matchers import find_licenses, clean_comments, parse_holders
 
+# initialize xdg cache before using it
+xdg.Mime.update_cache()
 
 PRINTABLE_BYTES = bytes(string.printable, encoding='ascii')
 
